==> cherokee-0.4.16.tar.gz: cherokee-0.4.16/src/thread.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/* Cherokee
 *
 * Authors:
 *      Alvaro Lopez Ortega <alvaro@alobbs.com>
 *
 * Copyright (C) 2001, 2002, 2003, 2004 Alvaro Lopez Ortega
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef __CHEROKEE_THREAD_H__
#define __CHEROKEE_THREAD_H__

#include "common.h"
#include "list.h"
#include "socket.h"
#include "connection.h"
#include "fdpoll.h"

#include <pthread.h>

typedef enum {
	thread_sync, 
	thread_async
} cherokee_thread_type_t;

typedef struct {
	struct list_head base;
	pthread_t        thread;

	cherokee_fdpoll_t      *fdpoll;
	cherokee_thread_type_t  thread_type;

	void   *server;
	int     exit;

	int     active_list_num;
	list_t  active_list;
	list_t  reuse_list;     
	int     pending_conns_num;      /* Waiting pipelining connections */

	struct {
		uint32_t continuous;
		uint32_t continuous_max;
		uint32_t recalculate;
		
	} accept;

} cherokee_thread_t;

#define THREAD(x)         ((cherokee_thread_t *)(x))
#define THREAD_SRV(t)     (SRV(THREAD(t)->server))
#define THREAD_IS_REAL(t) (THREAD(t)->real_thread)


#ifdef HAVE_PTHREAD
# define cherokee_thread_step(t,b) cherokee_thread_step_MULTI_THREAD(t,b)
ret_t cherokee_thread_step_MULTI_THREAD  (cherokee_thread_t *thd, cherokee_boolean_t dont_block);
#else
# define cherokee_thread_step(t,b) cherokee_thread_step_SINGLE_THREAD(t,b)
ret_t cherokee_thread_step_SINGLE_THREAD (cherokee_thread_t *thd, cherokee_boolean_t dont_block);
#endif

ret_t cherokee_thread_new  (cherokee_thread_t **thd, void *server, cherokee_thread_type_t type, int system_fd_num, int fd_num);
ret_t cherokee_thread_free (cherokee_thread_t  *thd);

ret_t cherokee_thread_get_new_connection      (cherokee_thread_t *thd, cherokee_connection_t **conn);
ret_t cherokee_thread_set_reusable_connection (cherokee_thread_t *thd, cherokee_connection_t  *conn);
ret_t cherokee_thread_add_connection          (cherokee_thread_t *thd, cherokee_connection_t  *conn);

ret_t cherokee_thread_add_incoming_socket     (cherokee_thread_t *thd, cherokee_socket_t *sock);

int   cherokee_thread_connection_num          (cherokee_thread_t *thd);
ret_t cherokee_thread_close_all_connections   (cherokee_thread_t *thd);

#endif /* __CHEROKEE_THREAD_H__ */

==> cherokee-0.4.17.1.tar.gz: cherokee-0.4.17/src/thread.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/* Cherokee
 *
 * Authors:
 *      Alvaro Lopez Ortega <alvaro@alobbs.com>
 *
 * Copyright (C) 2001, 2002, 2003, 2004 Alvaro Lopez Ortega
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef __CHEROKEE_THREAD_H__
#define __CHEROKEE_THREAD_H__

#include "common.h"

#ifdef HAVE_PTHREAD_H
# include <pthread.h>
#endif

#include "list.h"
#include "socket.h"
#include "connection.h"
#include "fdpoll.h"


typedef enum {
	thread_sync, 
	thread_async
} cherokee_thread_type_t;

typedef enum {
	thread_tls_normal,
	thread_normal_tls
} cherokee_thread_pref_t;


typedef struct {
	struct list_head base;

#ifdef HAVE_PTHREAD
	pthread_t thread;
#endif

	cherokee_fdpoll_t      *fdpoll;
	cherokee_thread_type_t  thread_type;
	cherokee_thread_pref_t  thread_pref;

	void   *server;
	int     exit;

	int     active_list_num;
	list_t  active_list;
	list_t  reuse_list;     
	int     pending_conns_num;      /* Waiting pipelining connections */

	struct {
		uint32_t continuous;
		uint32_t continuous_max;
		uint32_t recalculate;
		
	} accept;

} cherokee_thread_t;

#define THREAD(x)         ((cherokee_thread_t *)(x))
#define THREAD_SRV(t)     (SRV(THREAD(t)->server))
#define THREAD_IS_REAL(t) (THREAD(t)->real_thread)


#ifdef HAVE_PTHREAD
# define cherokee_thread_step(t,b) cherokee_thread_step_MULTI_THREAD(t,b)
ret_t cherokee_thread_step_MULTI_THREAD  (cherokee_thread_t *thd, cherokee_boolean_t dont_block);
#else
# define cherokee_thread_step(t,b) cherokee_thread_step_SINGLE_THREAD(t,b)
ret_t cherokee_thread_step_SINGLE_THREAD (cherokee_thread_t *thd, cherokee_boolean_t dont_block);
#endif

ret_t cherokee_thread_new  (cherokee_thread_t **thd, void *server, cherokee_thread_type_t type, int system_fd_num, int fd_num);
ret_t cherokee_thread_free (cherokee_thread_t  *thd);

ret_t cherokee_thread_get_new_connection      (cherokee_thread_t *thd, cherokee_connection_t **conn);
ret_t cherokee_thread_set_reusable_connection (cherokee_thread_t *thd, cherokee_connection_t  *conn);
ret_t cherokee_thread_add_connection          (cherokee_thread_t *thd, cherokee_connection_t  *conn);

ret_t cherokee_thread_add_incoming_socket     (cherokee_thread_t *thd, cherokee_socket_t *sock);

int   cherokee_thread_connection_num          (cherokee_thread_t *thd);
ret_t cherokee_thread_close_all_connections   (cherokee_thread_t *thd);

#endif /* __CHEROKEE_THREAD_H__ */
